@@ -19,11 +19,9 @@
 # along with duplicity; if not, write to the Free Software Foundation,
 # Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 
-from __future__ import print_function
-from future import standard_library
-standard_library.install_aliases()
 
 import sys
+
 try:
     import unittest.mock as mock
 except ImportError:
@@ -37,165 +35,167 @@ from duplicity import config
 from . import UnitTestCase
 
 
-@unittest.skipIf(sys.version_info[:2] < (3, 6), u"Skip on bad urllib.parse handling")
+@unittest.skipIf(sys.version_info[:2] < (3, 6), "Skip on bad urllib.parse handling")
 class ParsedUrlTest(UnitTestCase):
-    u"""Test the ParsedUrl class"""
+    """Test the ParsedUrl class"""
+
     def test_basic(self):
-        u"""Test various url strings"""
-        pu = duplicity.backend.ParsedUrl(u"scp://ben@foo.bar:1234/a/b")
-        assert pu.scheme == u"scp", pu.scheme
-        assert pu.netloc == u"ben@foo.bar:1234", pu.netloc
-        assert pu.path == u"/a/b", pu.path
-        assert pu.username == u"ben", pu.username
+        """Test various url strings"""
+        pu = duplicity.backend.ParsedUrl("scp://ben@foo.bar:1234/a/b")
+        assert pu.scheme == "scp", pu.scheme
+        assert pu.netloc == "ben@foo.bar:1234", pu.netloc
+        assert pu.path == "/a/b", pu.path
+        assert pu.username == "ben", pu.username
         assert pu.port == 1234, pu.port
-        assert pu.hostname == u"foo.bar", pu.hostname
+        assert pu.hostname == "foo.bar", pu.hostname
 
-        pu = duplicity.backend.ParsedUrl(u"ftp://foo.bar:1234/")
-        assert pu.scheme == u"ftp", pu.scheme
-        assert pu.netloc == u"foo.bar:1234", pu.netloc
-        assert pu.path == u"/", pu.path
+        pu = duplicity.backend.ParsedUrl("ftp://foo.bar:1234/")
+        assert pu.scheme == "ftp", pu.scheme
+        assert pu.netloc == "foo.bar:1234", pu.netloc
+        assert pu.path == "/", pu.path
         assert pu.username is None, pu.username
         assert pu.port == 1234, pu.port
-        assert pu.hostname == u"foo.bar", pu.hostname
+        assert pu.hostname == "foo.bar", pu.hostname
 
-        pu = duplicity.backend.ParsedUrl(u"file:///home")
-        assert pu.scheme == u"file", pu.scheme
-        assert pu.netloc == u"", pu.netloc
-        assert pu.path == u"///home", pu.path
+        pu = duplicity.backend.ParsedUrl("file:///home")
+        assert pu.scheme == "file", pu.scheme
+        assert pu.netloc == "", pu.netloc
+        assert pu.path == "///home", pu.path
         assert pu.username is None, pu.username
         assert pu.port is None, pu.port
 
-        pu = duplicity.backend.ParsedUrl(u"file://home")
-        assert pu.scheme == u"file", pu.scheme
-        assert pu.netloc == u"", pu.netloc
-        assert pu.path == u"//home", pu.path
+        pu = duplicity.backend.ParsedUrl("file://home")
+        assert pu.scheme == "file", pu.scheme
+        assert pu.netloc == "", pu.netloc
+        assert pu.path == "//home", pu.path
         assert pu.username is None, pu.username
         assert pu.port is None, pu.port
 
-        pu = duplicity.backend.ParsedUrl(u"ftp://foo@bar:pass@example.com:123/home")
-        assert pu.scheme == u"ftp", pu.scheme
-        assert pu.netloc == u"foo@bar:pass@example.com:123", pu.netloc
-        assert pu.hostname == u"example.com", pu.hostname
-        assert pu.path == u"/home", pu.path
-        assert pu.username == u"foo@bar", pu.username
-        assert pu.password == u"pass", pu.password
+        pu = duplicity.backend.ParsedUrl("ftp://foo@bar:pass@example.com:123/home")
+        assert pu.scheme == "ftp", pu.scheme
+        assert pu.netloc == "foo@bar:pass@example.com:123", pu.netloc
+        assert pu.hostname == "example.com", pu.hostname
+        assert pu.path == "/home", pu.path
+        assert pu.username == "foo@bar", pu.username
+        assert pu.password == "pass", pu.password
         assert pu.port == 123, pu.port
 
-        pu = duplicity.backend.ParsedUrl(u"ftp://foo%40bar:pass@example.com:123/home")
-        assert pu.scheme == u"ftp", pu.scheme
-        assert pu.netloc == u"foo%40bar:pass@example.com:123", pu.netloc
-        assert pu.hostname == u"example.com", pu.hostname
-        assert pu.path == u"/home", pu.path
-        assert pu.username == u"foo@bar", pu.username
-        assert pu.password == u"pass", pu.password
+        pu = duplicity.backend.ParsedUrl("ftp://foo%40bar:pass@example.com:123/home")
+        assert pu.scheme == "ftp", pu.scheme
+        assert pu.netloc == "foo%40bar:pass@example.com:123", pu.netloc
+        assert pu.hostname == "example.com", pu.hostname
+        assert pu.path == "/home", pu.path
+        assert pu.username == "foo@bar", pu.username
+        assert pu.password == "pass", pu.password
         assert pu.port == 123, pu.port
 
-        pu = duplicity.backend.ParsedUrl(u"imap://foo@bar:pass@example.com:123/home")
-        assert pu.scheme == u"imap", pu.scheme
-        assert pu.netloc == u"foo@bar:pass@example.com:123", pu.netloc
-        assert pu.hostname == u"example.com", pu.hostname
-        assert pu.path == u"/home", pu.path
-        assert pu.username == u"foo@bar", pu.username
-        assert pu.password == u"pass", pu.password
+        pu = duplicity.backend.ParsedUrl("imap://foo@bar:pass@example.com:123/home")
+        assert pu.scheme == "imap", pu.scheme
+        assert pu.netloc == "foo@bar:pass@example.com:123", pu.netloc
+        assert pu.hostname == "example.com", pu.hostname
+        assert pu.path == "/home", pu.path
+        assert pu.username == "foo@bar", pu.username
+        assert pu.password == "pass", pu.password
         assert pu.port == 123, pu.port
 
-        pu = duplicity.backend.ParsedUrl(u"imap://foo@bar@example.com:123/home")
-        assert pu.scheme == u"imap", pu.scheme
-        assert pu.netloc == u"foo@bar@example.com:123", pu.netloc
-        assert pu.hostname == u"example.com", pu.hostname
-        assert pu.path == u"/home", pu.path
-        assert pu.username == u"foo@bar", pu.username
+        pu = duplicity.backend.ParsedUrl("imap://foo@bar@example.com:123/home")
+        assert pu.scheme == "imap", pu.scheme
+        assert pu.netloc == "foo@bar@example.com:123", pu.netloc
+        assert pu.hostname == "example.com", pu.hostname
+        assert pu.path == "/home", pu.path
+        assert pu.username == "foo@bar", pu.username
         assert pu.password is None, pu.password
         assert pu.port == 123, pu.port
 
-        pu = duplicity.backend.ParsedUrl(u"imap://foo@bar@example.com/home")
-        assert pu.scheme == u"imap", pu.scheme
-        assert pu.netloc == u"foo@bar@example.com", pu.netloc
-        assert pu.hostname == u"example.com", pu.hostname
-        assert pu.path == u"/home", pu.path
-        assert pu.username == u"foo@bar", pu.username
+        pu = duplicity.backend.ParsedUrl("imap://foo@bar@example.com/home")
+        assert pu.scheme == "imap", pu.scheme
+        assert pu.netloc == "foo@bar@example.com", pu.netloc
+        assert pu.hostname == "example.com", pu.hostname
+        assert pu.path == "/home", pu.path
+        assert pu.username == "foo@bar", pu.username
         assert pu.password is None, pu.password
         assert pu.port is None, pu.port
 
-        pu = duplicity.backend.ParsedUrl(u"imap://foo@bar.com@example.com/home")
-        assert pu.scheme == u"imap", pu.scheme
-        assert pu.netloc == u"foo@bar.com@example.com", pu.netloc
-        assert pu.hostname == u"example.com", pu.hostname
-        assert pu.path == u"/home", pu.path
-        assert pu.username == u"foo@bar.com", pu.username
+        pu = duplicity.backend.ParsedUrl("imap://foo@bar.com@example.com/home")
+        assert pu.scheme == "imap", pu.scheme
+        assert pu.netloc == "foo@bar.com@example.com", pu.netloc
+        assert pu.hostname == "example.com", pu.hostname
+        assert pu.path == "/home", pu.path
+        assert pu.username == "foo@bar.com", pu.username
         assert pu.password is None, pu.password
         assert pu.port is None, pu.port
 
-        pu = duplicity.backend.ParsedUrl(u"imap://foo%40bar.com@example.com/home")
-        assert pu.scheme == u"imap", pu.scheme
-        assert pu.netloc == u"foo%40bar.com@example.com", pu.netloc
-        assert pu.hostname == u"example.com", pu.hostname
-        assert pu.path == u"/home", pu.path
-        assert pu.username == u"foo@bar.com", pu.username
+        pu = duplicity.backend.ParsedUrl("imap://foo%40bar.com@example.com/home")
+        assert pu.scheme == "imap", pu.scheme
+        assert pu.netloc == "foo%40bar.com@example.com", pu.netloc
+        assert pu.hostname == "example.com", pu.hostname
+        assert pu.path == "/home", pu.path
+        assert pu.username == "foo@bar.com", pu.username
         assert pu.password is None, pu.password
         assert pu.port is None, pu.port
 
-        pu = duplicity.backend.ParsedUrl(u"scheme://username:passwor@127.0.0.1:22/path/path")
-        assert pu.strip_auth() == u"scheme://127.0.0.1:22/path/path"
+        pu = duplicity.backend.ParsedUrl("scheme://username:passwor@127.0.0.1:22/path/path")
+        assert pu.strip_auth() == "scheme://127.0.0.1:22/path/path"
 
-        pu = duplicity.backend.ParsedUrl(u"xorriso:///dev/sr0")
-        assert pu.scheme == u"xorriso", pu.scheme
-        assert pu.path == u"///dev/sr0", pu.path
+        pu = duplicity.backend.ParsedUrl("xorriso:///dev/sr0")
+        assert pu.scheme == "xorriso", pu.scheme
+        assert pu.path == "///dev/sr0", pu.path
 
-        pu = duplicity.backend.ParsedUrl(u"xorriso:///dev/sr0:/path/on/iso")
-        assert pu.scheme == u"xorriso", pu.scheme
-        assert pu.path == u"///dev/sr0:/path/on/iso", pu.path
+        pu = duplicity.backend.ParsedUrl("xorriso:///dev/sr0:/path/on/iso")
+        assert pu.scheme == "xorriso", pu.scheme
+        assert pu.path == "///dev/sr0:/path/on/iso", pu.path
 
     def test_errors(self):
-        u"""Test various url errors"""
-        self.assertRaises(InvalidBackendURL, duplicity.backend.ParsedUrl,
-                          u"file:path")  # no relative paths for non-netloc schemes
-        self.assertRaises(UnsupportedBackendScheme, duplicity.backend.get_backend,
-                          u"ssh://foo@bar:pass@example.com/home")
+        """Test various url errors"""
+        self.assertRaises(
+            InvalidBackendURL, duplicity.backend.ParsedUrl, "file:path"
+        )  # no relative paths for non-netloc schemes
+        self.assertRaises(
+            UnsupportedBackendScheme,
+            duplicity.backend.get_backend,
+            "ssh://foo@bar:pass@example.com/home",
+        )
 
 
 class BackendWrapperTest(UnitTestCase):
-
     def setUp(self):
-        super(BackendWrapperTest, self).setUp()
+        super().setUp()
         self.mock = mock.MagicMock()
         self.backend = duplicity.backend.BackendWrapper(self.mock)
         self.local = mock.MagicMock()
-        self.remote = u'remote'
+        self.remote = "remote"
 
-    @mock.patch(u'sys.exit')
+    @mock.patch("sys.exit")
     def test_default_error_exit(self, exit_mock):
-        self.set_config(u'num_retries', 1)
+        self.set_config("num_retries", 1)
         try:
             del self.mock._error_code
-        except:
-            # Old versions of mock don't let you mark non-present attributes
-            # like this.
-            return  # can't use self.skip() since that needs py27
+        except Exception as e:
+            return
         self.mock._put.side_effect = Exception
         self.backend.put(self.local, self.remote)
         exit_mock.assert_called_once_with(50)
 
-    @mock.patch(u'sys.exit')
+    @mock.patch("sys.exit")
     def test_translates_code(self, exit_mock):
-        self.set_config(u'num_retries', 1)
+        self.set_config("num_retries", 1)
         self.mock._error_code.return_value = 12345
         self.mock._put.side_effect = Exception
         self.backend.put(self.local, self.remote)
         exit_mock.assert_called_once_with(12345)
 
-    @mock.patch(u'sys.exit')
+    @mock.patch("sys.exit")
     def test_uses_exception_code(self, exit_mock):
-        self.set_config(u'num_retries', 1)
+        self.set_config("num_retries", 1)
         self.mock._error_code.return_value = 12345
-        self.mock._put.side_effect = BackendException(u'error', code=54321)
+        self.mock._put.side_effect = BackendException("error", code=54321)
         self.backend.put(self.local, self.remote)
         exit_mock.assert_called_once_with(54321)
 
-    @mock.patch(u'sys.exit')
-    @mock.patch(u'time.sleep')  # so no waiting
+    @mock.patch("sys.exit")
+    @mock.patch("time.sleep")  # so no waiting
     def test_cleans_up(self, exit_mock, time_mock):  # pylint: disable=unused-argument
-        self.set_config(u'num_retries', 2)
+        self.set_config("num_retries", 2)
         self.mock._retry_cleanup.return_value = None
         self.mock._put.side_effect = Exception
         self.backend.put(self.local, self.remote)
@@ -209,7 +209,7 @@ class BackendWrapperTest(UnitTestCase):
         self.assertEqual(self.mock._delete_list.call_count, 1)
         try:
             del self.mock._delete_list
-        except:
+        except Exception as e:
             return
         self.backend.delete([self.remote])
         self.assertEqual(self.mock._delete.call_count, 1)
@@ -221,15 +221,15 @@ class BackendWrapperTest(UnitTestCase):
         self.assertEqual(self.mock._query_list.call_count, 1)
         try:
             del self.mock._query_list
-        except:
+        except Exception as e:
             return
         self.backend.query_info([self.remote])
         self.assertEqual(self.mock._query.call_count, 1)
 
-    @mock.patch(u'sys.exit')
-    @mock.patch(u'time.sleep')  # so no waiting
+    @mock.patch("sys.exit")
+    @mock.patch("time.sleep")  # so no waiting
     def test_retries(self, exit_mock, time_mock):  # pylint: disable=unused-argument
-        self.set_config(u'num_retries', 2)
+        self.set_config("num_retries", 2)
 
         self.mock._get.side_effect = Exception
         self.backend.get(self.remote, self.local)
@@ -253,7 +253,7 @@ class BackendWrapperTest(UnitTestCase):
 
         try:
             del self.mock._delete_list
-        except:
+        except Exception as e:
             return
         self.mock._delete.side_effect = Exception
         self.backend.delete([self.remote])
@@ -261,7 +261,7 @@ class BackendWrapperTest(UnitTestCase):
 
         try:
             del self.mock._query_list
-        except:
+        except Exception as e:
             return
         self.mock._query.side_effect = Exception
         self.backend.query_info([self.remote])
@@ -287,7 +287,7 @@ class BackendWrapperTest(UnitTestCase):
     def test_move_fallback_undefined(self):
         try:
             del self.mock._move
-        except:
+        except Exception as e:
             return
         self.backend.move(self.local, self.remote)
         self.mock._put.assert_called_once_with(self.local, self.remote)
@@ -299,5 +299,5 @@ class BackendWrapperTest(UnitTestCase):
         self.mock._close.assert_called_once_with()
 
 
-if __name__ == u"__main__":
+if __name__ == "__main__":
     unittest.main()
